netapp_ontap.models.vdi_on_nas API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.vdi_on_nas`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VdiOnNasSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VdiOnNas object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `desktops GET POST PATCH`

    The desktops field of the vdi_on_nas.

  `hyper_v_access GET POST`

    The hyper_v_access field of the vdi_on_nas.

  `nfs_access GET POST`

    The list of NFS access controls. You must provide either 'host' or 'access' to enable NFS access.

  `protection_type GET POST PATCH`

    The protection_type field of the vdi_on_nas.